@@ -2,11 +2,9 @@ import logging
 
 import requests
 
-from skyhub.loggin_config import *
 from skyhub.models.produto import Produto
 
-logger = logging.getLogger(__name__)
-logger.addHandler(f_handler)
+logger = logging.Logger(__name__)
 
 
 class SkyhubController:
